@@ -52,6 +52,7 @@ from josepy.json_util import (
     encode_cert,
     encode_csr,
     encode_hex16,
+    field,
 )
 
 from josepy.jwa import (
@@ -65,6 +66,9 @@ from josepy.jwa import (
     RS256,
     RS384,
     RS512,
+    ES256,
+    ES384,
+    ES512,
 )
 
 from josepy.jwk import (
