@@ -1,4 +1,5 @@
 """JOSE errors."""
+from typing import Any
 
 
 class Error(Exception):
@@ -8,9 +9,9 @@ class Error(Exception):
 class DeserializationError(Error):
     """JSON deserialization error."""
 
-    def __str__(self):
+    def __str__(self) -> str:
         return "Deserialization error: {0}".format(
-            super(DeserializationError, self).__str__())
+            super().__str__())
 
 
 class SerializationError(Error):
@@ -25,11 +26,11 @@ class UnrecognizedTypeError(DeserializationError):
 
     """
 
-    def __init__(self, typ, jobj):
+    def __init__(self, typ: str, jobj: Any) -> None:
         self.typ = typ
         self.jobj = jobj
-        super(UnrecognizedTypeError, self).__init__(str(self))
+        super().__init__(str(self))
 
-    def __str__(self):
+    def __str__(self) -> str:
         return '{0} was not recognized, full message: {1}'.format(
             self.typ, self.jobj)
