@@ -1,22 +1,17 @@
 """JOSE interfaces."""
 import abc
 import json
+from typing import Any
 
-import six
+from josepy import errors
 
-from josepy import errors, util
-
-try:
-    from collections.abc import Sequence, Mapping  # pylint: disable=import-error
-except ImportError:
-    from collections import Sequence, Mapping
+from collections.abc import Sequence, Mapping
 
 # pylint: disable=no-self-argument,no-method-argument,no-init,inherit-non-class
 # pylint: disable=too-few-public-methods
 
 
-@six.add_metaclass(abc.ABCMeta)
-class JSONDeSerializable(object):
+class JSONDeSerializable(object, metaclass=abc.ABCMeta):
     # pylint: disable=too-few-public-methods
     """Interface for (de)serializable JSON objects.
 
@@ -105,7 +100,7 @@ class JSONDeSerializable(object):
     """
 
     @abc.abstractmethod
-    def to_partial_json(self):  # pragma: no cover
+    def to_partial_json(self) -> Any:  # pragma: no cover
         """Partially serialize.
 
         Following the example, **partial serialization** means the following::
@@ -123,7 +118,7 @@ class JSONDeSerializable(object):
         """
         raise NotImplementedError()
 
-    def to_json(self):
+    def to_json(self) -> Any:
         """Fully serialize.
 
         Again, following the example from before, **full serialization**
@@ -136,10 +131,10 @@ class JSONDeSerializable(object):
         :returns: Fully serialized object.
 
         """
-        def _serialize(obj):
+        def _serialize(obj: Any) -> Any:
             if isinstance(obj, JSONDeSerializable):
                 return _serialize(obj.to_partial_json())
-            if isinstance(obj, six.string_types):  # strings are Sequence
+            if isinstance(obj, str):  # strings are Sequence
                 return obj
             elif isinstance(obj, list):
                 return [_serialize(subobj) for subobj in obj]
@@ -148,15 +143,16 @@ class JSONDeSerializable(object):
                 # unhashable list
                 return tuple(_serialize(subobj) for subobj in obj)
             elif isinstance(obj, Mapping):
-                return dict((_serialize(key), _serialize(value))
-                            for key, value in six.iteritems(obj))
+                return {_serialize(key): _serialize(value)
+                        for key, value in obj.items()}
             else:
                 return obj
 
         return _serialize(self)
 
-    @util.abstractclassmethod
-    def from_json(cls, jobj):  # pylint: disable=unused-argument
+    @classmethod
+    @abc.abstractmethod
+    def from_json(cls, jobj: Any) -> 'JSONDeSerializable':
         """Deserialize a decoded JSON document.
 
         :param jobj: Python object, composed of only other basic data
@@ -174,7 +170,7 @@ class JSONDeSerializable(object):
         return cls()  # pylint: disable=abstract-class-instantiated
 
     @classmethod
-    def json_loads(cls, json_string):
+    def json_loads(cls, json_string: str) -> 'JSONDeSerializable':
         """Deserialize from JSON document string."""
         try:
             loads = json.loads(json_string)
@@ -182,7 +178,7 @@ class JSONDeSerializable(object):
             raise errors.DeserializationError(error)
         return cls.from_json(loads)
 
-    def json_dumps(self, **kwargs):
+    def json_dumps(self, **kwargs: Any) -> str:
         """Dump to JSON string using proper serializer.
 
         :returns: JSON document string.
@@ -191,7 +187,7 @@ class JSONDeSerializable(object):
         """
         return json.dumps(self, default=self.json_dump_default, **kwargs)
 
-    def json_dumps_pretty(self):
+    def json_dumps_pretty(self) -> str:
         """Dump the object to pretty JSON document string.
 
         :rtype: str
@@ -200,7 +196,7 @@ class JSONDeSerializable(object):
         return self.json_dumps(sort_keys=True, indent=4, separators=(',', ': '))
 
     @classmethod
-    def json_dump_default(cls, python_object):
+    def json_dump_default(cls, python_object: 'JSONDeSerializable') -> Any:
         """Serialize Python object.
 
         This function is meant to be passed as ``default`` to
